@@ -1,5 +1,11 @@
 # -*- coding: utf-8 -*-
 
+XDGS = ('XDG_CONFIG_DIRS', 'XDG_DATA_HOME',
+        'XDG_CONFIG_HOME', 'XDG_DATA_DIRS',
+                          'XDG_CACHE_HOME',
+                          'XDG_STATE_HOME',
+                         'XDG_RUNTIME_DIR')
+
 GREEKOUT = {}
 
 GREEKOUT['lorem'] = """
